==> CGAL-6.0.1-doc_html.tar.xz: doc_html/Manual/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "CGAL 6.0.1 - Manual", "index.html", [
    [ "Getting Started with CGAL", "general_intro.html", "general_intro" ],
    [ "Tutorials", "tutorials.html", "tutorials" ],
    [ "Package Overview", "packages.html", [
      [ "Arithmetic and Algebra", "packages.html#PartAlgebraicFoundations", [
        [ "Algebraic Foundations", "packages.html#PkgAlgebraicFoundations", null ],
        [ "Number Types", "packages.html#PkgNumberTypes", null ],
        [ "Modular Arithmetic", "packages.html#PkgModularArithmetic", null ],
        [ "Polynomial", "packages.html#PkgPolynomial", null ],
        [ "Algebraic Kernel", "packages.html#PkgAlgebraicKernelD", null ]
      ] ],
      [ "Combinatorial Algorithms", "packages.html#PartCombinatorialAlgorithms", [
        [ "Monotone and Sorted Matrix Search", "packages.html#PkgMatrixSearch", null ],
        [ "Linear and Quadratic Programming Solver", "packages.html#PkgQPSolver", null ]
      ] ],
      [ "Geometry Kernels", "packages.html#PartKernels", [
        [ "2D and 3D Linear Geometry Kernel", "packages.html#PkgKernel23", null ],
        [ "dD Geometry Kernel", "packages.html#PkgKernelD", null ],
        [ "2D Circular Geometry Kernel", "packages.html#PkgCircularKernel2", null ],
        [ "3D Spherical Geometry Kernel", "packages.html#PkgCircularKernel3", null ]
      ] ],
      [ "Convex Hull Algorithms", "packages.html#PartConvexHullAlgorithms", [
        [ "2D Convex Hulls and Extreme Points", "packages.html#PkgConvexHull2", null ],
        [ "3D Convex Hulls", "packages.html#PkgConvexHull3", null ],
        [ "dD Convex Hulls and Delaunay Triangulations", "packages.html#PkgConvexHullD", null ]
      ] ],
      [ "Polygons", "packages.html#PartPolygons", [
        [ "2D Polygons", "packages.html#PkgPolygon2", null ],
        [ "2D Polygon Repair", "packages.html#PkgPolygonRepair", null ],
        [ "2D Regularized Boolean Set-Operations", "packages.html#PkgBooleanSetOperations2", null ],
        [ "2D Boolean Operations on Nef Polygons", "packages.html#PkgNef2", null ],
        [ "2D Boolean Operations on Nef Polygons Embedded on the Sphere", "packages.html#PkgNefS2", null ],
        [ "2D Polygon Partitioning", "packages.html#PkgPartition2", null ],
        [ "2D Straight Skeleton and Polygon Offsetting", "packages.html#PkgStraightSkeleton2", null ],
        [ "2D Minkowski Sums", "packages.html#PkgMinkowskiSum2", null ],
        [ "2D Polyline Simplification", "packages.html#PkgPolylineSimplification2", null ],
        [ "2D Visibility Computation", "packages.html#PkgVisibility2", null ],
        [ "2D Movable Separability of Sets", "packages.html#PkgSetMovableSeparability2", null ]
      ] ],
      [ "Cell Complexes and Polyhedra", "packages.html#PartPolyhedra", [
        [ "3D Polyhedral Surface", "packages.html#PkgPolyhedron", null ],
        [ "Halfedge Data Structures", "packages.html#PkgHalfedgeDS", null ],
        [ "Surface Mesh", "packages.html#PkgSurfaceMesh", null ],
        [ "Combinatorial Maps", "packages.html#PkgCombinatorialMaps", null ],
        [ "Generalized Maps", "packages.html#PkgGeneralizedMaps", null ],
        [ "Linear Cell Complex", "packages.html#PkgLinearCellComplex", null ],
        [ "3D Boolean Operations on Nef Polyhedra", "packages.html#PkgNef3", null ],
        [ "Convex Decomposition of Polyhedra", "packages.html#PkgConvexDecomposition3", null ],
        [ "3D Minkowski Sum of Polyhedra", "packages.html#PkgMinkowskiSum3", null ]
      ] ],
      [ "Arrangements", "packages.html#PartArrangements", [
        [ "2D Arrangements", "packages.html#PkgArrangementOnSurface2", null ],
        [ "2D Intersection of Curves", "packages.html#PkgSurfaceSweep2", null ],
        [ "2D Snap Rounding", "packages.html#PkgSnapRounding2", null ],
        [ "2D Envelopes", "packages.html#PkgEnvelope2", null ],
        [ "3D Envelopes", "packages.html#PkgEnvelope3", null ]
      ] ],
      [ "Triangulations and Delaunay Triangulations", "packages.html#PartTriangulationsAndDelaunayTriangulations", [
        [ "2D Triangulations", "packages.html#PkgTriangulation2", null ],
        [ "2D Triangulation Data Structure", "packages.html#PkgTDS2", null ],
        [ "2D Triangulations on the Sphere", "packages.html#PkgTriangulationOnSphere2", null ],
        [ "2D Periodic Triangulations", "packages.html#PkgPeriodic2Triangulation2", null ],
        [ "2D Hyperbolic Delaunay Triangulations", "packages.html#PkgHyperbolicTriangulation2", null ],
        [ "2D Periodic Hyperbolic Triangulations", "packages.html#PkgPeriodic4HyperbolicTriangulation2", null ],
        [ "3D Triangulations", "packages.html#PkgTriangulation3", null ],
        [ "3D Triangulation Data Structure", "packages.html#PkgTDS3", null ],
        [ "3D Periodic Triangulations", "packages.html#PkgPeriodic3Triangulation3", null ],
        [ "dD Triangulations", "packages.html#PkgTriangulations", null ],
        [ "2D Alpha Shapes", "packages.html#PkgAlphaShapes2", null ],
        [ "3D Alpha Shapes", "packages.html#PkgAlphaShapes3", null ]
      ] ],
      [ "Voronoi Diagrams", "packages.html#PartVoronoiDiagrams", [
        [ "2D Segment Delaunay Graphs", "packages.html#PkgSegmentDelaunayGraph2", null ],
        [ "L Infinity Segment Delaunay Graphs", "packages.html#PkgSegmentDelaunayGraphLinf2", null ],
        [ "2D Apollonius Graphs (Delaunay Graphs of Disks)", "packages.html#PkgApolloniusGraph2", null ],
        [ "2D Voronoi Diagram Adaptor", "packages.html#PkgVoronoiDiagram2", null ]
      ] ],
      [ "Mesh Generation", "packages.html#PartMeshing", [
        [ "2D Conforming Triangulations and Meshes", "packages.html#PkgMesh2", null ],
        [ "3D Surface Mesh Generation", "packages.html#PkgSurfaceMesher3", null ],
        [ "3D Skin Surface Meshing", "packages.html#PkgSkinSurface3", null ],
        [ "3D Simplicial Mesh Data Structure", "packages.html#PkgSMDS3", null ],
        [ "3D Mesh Generation", "packages.html#PkgMesh3", null ],
        [ "Tetrahedral Remeshing", "packages.html#PkgTetrahedralRemeshing", null ],
        [ "3D Periodic Mesh Generation", "packages.html#PkgPeriodic3Mesh3", null ],
        [ "3D Alpha Wrapping", "packages.html#PkgAlphaWrap3", null ]
      ] ],
      [ "Shape Reconstruction", "packages.html#PartReconstruction", [
        [ "Poisson Surface Reconstruction", "packages.html#PkgPoissonSurfaceReconstruction3", null ],
        [ "Scale-Space Surface Reconstruction", "packages.html#PkgScaleSpaceReconstruction3", null ],
        [ "Advancing Front Surface Reconstruction", "packages.html#PkgAdvancingFrontSurfaceReconstruction", null ],
        [ "Polygonal Surface Reconstruction", "packages.html#PkgPolygonalSurfaceReconstruction", null ],
        [ "Kinetic Space Partition", "packages.html#PkgKineticSpacePartition", null ],
        [ "Kinetic Surface Reconstruction", "packages.html#PkgKineticSurfaceReconstruction", null ],
        [ "Optimal Transportation Curve Reconstruction", "packages.html#PkgOptimalTransportationReconstruction2", null ]
      ] ],
      [ "Geometry Processing", "packages.html#PartGeometryProcessing", [
        [ "Polygon Mesh Processing", "packages.html#PkgPolygonMeshProcessing", null ],
        [ "3D Surface Subdivision Methods", "packages.html#PkgSurfaceSubdivisionMethod3", null ],
        [ "Triangulated Surface Mesh Segmentation", "packages.html#PkgSurfaceMeshSegmentation", null ],
        [ "Triangulated Surface Mesh Simplification", "packages.html#PkgSurfaceMeshSimplification", null ],
        [ "Triangulated Surface Mesh Deformation", "packages.html#PkgSurfaceMeshDeformation", null ],
        [ "Triangulated Surface Mesh Parameterization", "packages.html#PkgSurfaceMeshParameterization", null ],
        [ "Triangulated Surface Mesh Shortest Paths", "packages.html#PkgSurfaceMeshShortestPath", null ],
        [ "Triangulated Surface Mesh Skeletonization", "packages.html#PkgSurfaceMeshSkeletonization", null ],
        [ "Triangulated Surface Mesh Approximation", "packages.html#PkgTSMA", null ],
        [ "Approximation of Ridges and Umbilics on Triangulated Surface Meshes", "packages.html#PkgRidges3", null ],
        [ "Estimation of Local Differential Properties of Point-Sampled Surfaces", "packages.html#PkgJetFitting3", null ],
        [ "3D Point Set", "packages.html#PkgPointSet3", null ],
        [ "Point Set Processing", "packages.html#PkgPointSetProcessing3", null ],
        [ "Shape Detection", "packages.html#PkgShapeDetection", null ],
        [ "Shape Regularization", "packages.html#PkgShapeRegularization", null ],
        [ "2D Placement of Streamlines", "packages.html#PkgStreamLines2", null ],
        [ "Classification", "packages.html#PkgClassification", null ],
        [ "The Heat Method", "packages.html#PkgHeatMethod", null ],
        [ "Surface Mesh Topology", "packages.html#PkgSurfaceMeshTopology", null ]
      ] ],
      [ "Spatial Searching and Sorting", "packages.html#PartSearchStructures", [
        [ "2D Range and Neighbor Search", "packages.html#PkgPointSet2", null ],
        [ "Interval Skip List", "packages.html#PkgIntervalSkipList", null ],
        [ "dD Spatial Searching", "packages.html#PkgSpatialSearchingD", null ],
        [ "dD Range and Segment Trees", "packages.html#PkgSearchStructures", null ],
        [ "Intersecting Sequences of dD Iso-oriented Boxes", "packages.html#PkgBoxIntersectionD", null ],
        [ "2D and 3D Fast Intersection and Distance Computation", "packages.html#PkgAABBTree", null ],
        [ "Quadtrees, Octrees, and Orthtrees", "packages.html#PkgOrthtree", null ],
        [ "Spatial Sorting", "packages.html#PkgSpatialSorting", null ]
      ] ],
      [ "Geometric Optimization", "packages.html#PartGeometricOptimization", [
        [ "Bounding Volumes", "packages.html#PkgBoundingVolumes", null ],
        [ "Inscribed Areas", "packages.html#PkgInscribedAreas", null ],
        [ "Optimal Distances", "packages.html#PkgPolytopeDistanceD", null ],
        [ "Principal Component Analysis", "packages.html#PkgPrincipalComponentAnalysisD", null ],
        [ "Optimal Bounding Box", "packages.html#PkgOptimalBoundingBox", null ]
      ] ],
      [ "Interpolation", "packages.html#PartInterpolation", [
        [ "2D and Surface Function Interpolation", "packages.html#PkgInterpolation2", null ],
        [ "2D Generalized Barycentric Coordinates", "packages.html#PkgBarycentricCoordinates2", null ]
      ] ],
      [ "Support Library", "packages.html#PartSupportLibrary", [
        [ "STL Extensions for CGAL", "packages.html#PkgSTLExtension", null ],
        [ "CGAL and the Boost Graph Library", "packages.html#PkgBGL", null ],
        [ "CGAL and Solvers", "packages.html#PkgSolverInterface", null ],
        [ "CGAL and Boost Property Maps", "packages.html#PkgPropertyMap", null ],
        [ "Weight Interface", "packages.html#PkgWeights", null ],
        [ "Cone-Based Spanners", "packages.html#PkgConeSpanners2", null ],
        [ "Handles and Circulators", "packages.html#PkgHandlesAndCirculators", null ],
        [ "Geometric Object Generators", "packages.html#PkgGenerators", null ],
        [ "Profiling tools, Hash Map, Union-find, Modifiers", "packages.html#Miscellany", null ],
        [ "I/O Streams", "packages.html#PkgStreamSupport", null ]
      ] ],
      [ "Visualization", "packages.html#PartVisualization", [
        [ "CGAL and the Qt Graphics View Framework", "packages.html#PkgGraphicsView", null ],
        [ "CGAL Ipelets", "packages.html#PkgCGALIpelets", null ],
        [ "Basic Viewer", "packages.html#PkgBasicViewer", null ]
      ] ]
    ] ],
    [ "Developer Manual", "dev_manual.html", "dev_manual" ],
    [ "License", "license.html", [
      [ "GNU GPL", "license.html#licensesGPL", null ],
      [ "GNU LGPL", "license.html#licensesLGPL", null ],
      [ "Rationale of the License Choice", "license.html#licensesRationale", null ],
      [ "Commercial Licenses", "license.html#licensesCommercial", null ],
      [ "License Checking", "license.html#licenseCheck", null ],
      [ "Determining the license of a CGAL file", "license.html#licensesWhere", null ]
    ] ],
    [ "Acknowledging CGAL", "how_to_cite_cgal.html", null ],
    [ "Bibliography", "citelist.html", null ]
  ] ]
];

var NAVTREEINDEX =
[
"citelist.html",
"packages.html#PkgPartition2"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> CGAL-6.1-doc_html.tar.xz: doc_html/Manual/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "CGAL 6.1 - Manual", "index.html", [
    [ "Getting Started with CGAL", "general_intro.html", "general_intro" ],
    [ "Tutorials", "tutorials.html", "tutorials" ],
    [ "Package Overview", "packages.html", [
      [ "Arithmetic and Algebra", "packages.html#PartAlgebraicFoundations", [
        [ "Algebraic Foundations", "packages.html#PkgAlgebraicFoundations", null ],
        [ "Number Types", "packages.html#PkgNumberTypes", null ],
        [ "Modular Arithmetic", "packages.html#PkgModularArithmetic", null ],
        [ "Polynomial", "packages.html#PkgPolynomial", null ],
        [ "Algebraic Kernel", "packages.html#PkgAlgebraicKernelD", null ]
      ] ],
      [ "Combinatorial Algorithms", "packages.html#PartCombinatorialAlgorithms", [
        [ "Monotone and Sorted Matrix Search", "packages.html#PkgMatrixSearch", null ],
        [ "Linear and Quadratic Programming Solver", "packages.html#PkgQPSolver", null ]
      ] ],
      [ "Geometry Kernels", "packages.html#PartKernels", [
        [ "2D and 3D Linear Geometry Kernel", "packages.html#PkgKernel23", null ],
        [ "dD Geometry Kernel", "packages.html#PkgKernelD", null ],
        [ "2D Circular Geometry Kernel", "packages.html#PkgCircularKernel2", null ],
        [ "3D Spherical Geometry Kernel", "packages.html#PkgCircularKernel3", null ]
      ] ],
      [ "Convex Hull Algorithms", "packages.html#PartConvexHullAlgorithms", [
        [ "2D Convex Hulls and Extreme Points", "packages.html#PkgConvexHull2", null ],
        [ "3D Convex Hulls", "packages.html#PkgConvexHull3", null ],
        [ "dD Convex Hulls and Delaunay Triangulations", "packages.html#PkgConvexHullD", null ]
      ] ],
      [ "Polygons", "packages.html#PartPolygons", [
        [ "2D Polygons", "packages.html#PkgPolygon2", null ],
        [ "2D Polygon Repair", "packages.html#PkgPolygonRepair", null ],
        [ "2D Regularized Boolean Set-Operations", "packages.html#PkgBooleanSetOperations2", null ],
        [ "2D Boolean Operations on Nef Polygons", "packages.html#PkgNef2", null ],
        [ "2D Boolean Operations on Nef Polygons Embedded on the Sphere", "packages.html#PkgNefS2", null ],
        [ "2D Polygon Partitioning", "packages.html#PkgPartition2", null ],
        [ "2D Straight Skeleton and Polygon Offsetting", "packages.html#PkgStraightSkeleton2", null ],
        [ "2D Minkowski Sums", "packages.html#PkgMinkowskiSum2", null ],
        [ "2D Polyline Simplification", "packages.html#PkgPolylineSimplification2", null ],
        [ "dD Fréchet Distance", "packages.html#PkgFrechetDistance", null ],
        [ "2D Visibility Computation", "packages.html#PkgVisibility2", null ],
        [ "2D Movable Separability of Sets", "packages.html#PkgSetMovableSeparability2", null ]
      ] ],
      [ "Cell Complexes and Polyhedra", "packages.html#PartPolyhedra", [
        [ "3D Polyhedral Surface", "packages.html#PkgPolyhedron", null ],
        [ "Halfedge Data Structures", "packages.html#PkgHalfedgeDS", null ],
        [ "Surface Mesh", "packages.html#PkgSurfaceMesh", null ],
        [ "Combinatorial Maps", "packages.html#PkgCombinatorialMaps", null ],
        [ "Generalized Maps", "packages.html#PkgGeneralizedMaps", null ],
        [ "Linear Cell Complex", "packages.html#PkgLinearCellComplex", null ],
        [ "3D Boolean Operations on Nef Polyhedra", "packages.html#PkgNef3", null ],
        [ "Convex Decomposition of Polyhedra", "packages.html#PkgConvexDecomposition3", null ],
        [ "3D Minkowski Sum of Polyhedra", "packages.html#PkgMinkowskiSum3", null ]
      ] ],
      [ "Arrangements", "packages.html#PartArrangements", [
        [ "2D Arrangements", "packages.html#PkgArrangementOnSurface2", null ],
        [ "2D Intersection of Curves", "packages.html#PkgSurfaceSweep2", null ],
        [ "2D Snap Rounding", "packages.html#PkgSnapRounding2", null ],
        [ "2D Envelopes", "packages.html#PkgEnvelope2", null ],
        [ "3D Envelopes", "packages.html#PkgEnvelope3", null ]
      ] ],
      [ "Triangulations and Delaunay Triangulations", "packages.html#PartTriangulationsAndDelaunayTriangulations", [
        [ "2D Triangulations", "packages.html#PkgTriangulation2", null ],
        [ "2D Triangulation Data Structure", "packages.html#PkgTDS2", null ],
        [ "2D Triangulations on the Sphere", "packages.html#PkgTriangulationOnSphere2", null ],
        [ "2D Periodic Triangulations", "packages.html#PkgPeriodic2Triangulation2", null ],
        [ "2D Hyperbolic Delaunay Triangulations", "packages.html#PkgHyperbolicTriangulation2", null ],
        [ "2D Triangulations on Hyperbolic Surfaces", "packages.html#PkgHyperbolicSurfaceTriangulation2", null ],
        [ "2D Periodic Hyperbolic Triangulations", "packages.html#PkgPeriodic4HyperbolicTriangulation2", null ],
        [ "3D Triangulations", "packages.html#PkgTriangulation3", null ],
        [ "3D Triangulation Data Structure", "packages.html#PkgTDS3", null ],
        [ "3D Constrained Triangulations", "packages.html#PkgConstrainedTriangulation3", null ],
        [ "3D Periodic Triangulations", "packages.html#PkgPeriodic3Triangulation3", null ],
        [ "dD Triangulations", "packages.html#PkgTriangulations", null ],
        [ "2D Alpha Shapes", "packages.html#PkgAlphaShapes2", null ],
        [ "3D Alpha Shapes", "packages.html#PkgAlphaShapes3", null ]
      ] ],
      [ "Voronoi Diagrams", "packages.html#PartVoronoiDiagrams", [
        [ "2D Segment Delaunay Graphs", "packages.html#PkgSegmentDelaunayGraph2", null ],
        [ "L Infinity Segment Delaunay Graphs", "packages.html#PkgSegmentDelaunayGraphLinf2", null ],
        [ "2D Apollonius Graphs (Delaunay Graphs of Disks)", "packages.html#PkgApolloniusGraph2", null ],
        [ "2D Voronoi Diagram Adaptor", "packages.html#PkgVoronoiDiagram2", null ]
      ] ],
      [ "Mesh Generation", "packages.html#PartMeshing", [
        [ "2D Conforming Triangulations and Meshes", "packages.html#PkgMesh2", null ],
        [ "3D Surface Mesh Generation", "packages.html#PkgSurfaceMesher3", null ],
        [ "3D Skin Surface Meshing", "packages.html#PkgSkinSurface3", null ],
        [ "3D Simplicial Mesh Data Structure", "packages.html#PkgSMDS3", null ],
        [ "3D Mesh Generation", "packages.html#PkgMesh3", null ],
        [ "3D Isosurfacing", "packages.html#PkgIsosurfacing3", null ],
        [ "Tetrahedral Remeshing", "packages.html#PkgTetrahedralRemeshing", null ],
        [ "3D Periodic Mesh Generation", "packages.html#PkgPeriodic3Mesh3", null ],
        [ "3D Alpha Wrapping", "packages.html#PkgAlphaWrap3", null ]
      ] ],
      [ "Shape Reconstruction", "packages.html#PartReconstruction", [
        [ "Poisson Surface Reconstruction", "packages.html#PkgPoissonSurfaceReconstruction3", null ],
        [ "Scale-Space Surface Reconstruction", "packages.html#PkgScaleSpaceReconstruction3", null ],
        [ "Advancing Front Surface Reconstruction", "packages.html#PkgAdvancingFrontSurfaceReconstruction", null ],
        [ "Polygonal Surface Reconstruction", "packages.html#PkgPolygonalSurfaceReconstruction", null ],
        [ "Kinetic Space Partition", "packages.html#PkgKineticSpacePartition", null ],
        [ "Kinetic Surface Reconstruction", "packages.html#PkgKineticSurfaceReconstruction", null ],
        [ "Optimal Transportation Curve Reconstruction", "packages.html#PkgOptimalTransportationReconstruction2", null ]
      ] ],
      [ "Geometry Processing", "packages.html#PartGeometryProcessing", [
        [ "Polygon Mesh Processing", "packages.html#PkgPolygonMeshProcessing", null ],
        [ "3D Surface Subdivision Methods", "packages.html#PkgSurfaceSubdivisionMethod3", null ],
        [ "Triangulated Surface Mesh Segmentation", "packages.html#PkgSurfaceMeshSegmentation", null ],
        [ "Triangulated Surface Mesh Simplification", "packages.html#PkgSurfaceMeshSimplification", null ],
        [ "Triangulated Surface Mesh Deformation", "packages.html#PkgSurfaceMeshDeformation", null ],
        [ "Triangulated Surface Mesh Parameterization", "packages.html#PkgSurfaceMeshParameterization", null ],
        [ "Triangulated Surface Mesh Shortest Paths", "packages.html#PkgSurfaceMeshShortestPath", null ],
        [ "Triangulated Surface Mesh Skeletonization", "packages.html#PkgSurfaceMeshSkeletonization", null ],
        [ "Triangulated Surface Mesh Approximation", "packages.html#PkgTSMA", null ],
        [ "Approximation of Ridges and Umbilics on Triangulated Surface Meshes", "packages.html#PkgRidges3", null ],
        [ "Estimation of Local Differential Properties of Point-Sampled Surfaces", "packages.html#PkgJetFitting3", null ],
        [ "3D Point Set", "packages.html#PkgPointSet3", null ],
        [ "Point Set Processing", "packages.html#PkgPointSetProcessing3", null ],
        [ "Shape Detection", "packages.html#PkgShapeDetection", null ],
        [ "Shape Regularization", "packages.html#PkgShapeRegularization", null ],
        [ "2D Placement of Streamlines", "packages.html#PkgStreamLines2", null ],
        [ "Classification", "packages.html#PkgClassification", null ],
        [ "The Heat Method", "packages.html#PkgHeatMethod", null ],
        [ "Surface Mesh Topology", "packages.html#PkgSurfaceMeshTopology", null ]
      ] ],
      [ "Spatial Searching and Sorting", "packages.html#PartSearchStructures", [
        [ "2D Range and Neighbor Search", "packages.html#PkgPointSet2", null ],
        [ "Interval Skip List", "packages.html#PkgIntervalSkipList", null ],
        [ "dD Spatial Searching", "packages.html#PkgSpatialSearchingD", null ],
        [ "dD Range and Segment Trees", "packages.html#PkgSearchStructures", null ],
        [ "Intersecting Sequences of dD Iso-oriented Boxes", "packages.html#PkgBoxIntersectionD", null ],
        [ "2D and 3D Fast Intersection and Distance Computation", "packages.html#PkgAABBTree", null ],
        [ "Quadtrees, Octrees, and Orthtrees", "packages.html#PkgOrthtree", null ],
        [ "Spatial Sorting", "packages.html#PkgSpatialSorting", null ]
      ] ],
      [ "Geometric Optimization", "packages.html#PartGeometricOptimization", [
        [ "Bounding Volumes", "packages.html#PkgBoundingVolumes", null ],
        [ "Inscribed Areas", "packages.html#PkgInscribedAreas", null ],
        [ "Optimal Distances", "packages.html#PkgPolytopeDistanceD", null ],
        [ "Principal Component Analysis", "packages.html#PkgPrincipalComponentAnalysisD", null ],
        [ "Optimal Bounding Box", "packages.html#PkgOptimalBoundingBox", null ]
      ] ],
      [ "Interpolation", "packages.html#PartInterpolation", [
        [ "2D and Surface Function Interpolation", "packages.html#PkgInterpolation2", null ],
        [ "2D Generalized Barycentric Coordinates", "packages.html#PkgBarycentricCoordinates2", null ]
      ] ],
      [ "Support Library", "packages.html#PartSupportLibrary", [
        [ "STL Extensions for CGAL", "packages.html#PkgSTLExtension", null ],
        [ "CGAL and the Boost Graph Library", "packages.html#PkgBGL", null ],
        [ "CGAL and Solvers", "packages.html#PkgSolverInterface", null ],
        [ "CGAL and Boost Property Maps", "packages.html#PkgPropertyMap", null ],
        [ "Weight Interface", "packages.html#PkgWeights", null ],
        [ "Cone-Based Spanners", "packages.html#PkgConeSpanners2", null ],
        [ "Handles and Circulators", "packages.html#PkgHandlesAndCirculators", null ],
        [ "Geometric Object Generators", "packages.html#PkgGenerators", null ],
        [ "Profiling tools, Hash Map, Union-find, Modifiers", "packages.html#Miscellany", null ],
        [ "I/O Streams", "packages.html#PkgStreamSupport", null ]
      ] ],
      [ "Visualization", "packages.html#PartVisualization", [
        [ "CGAL and the Qt Graphics View Framework", "packages.html#PkgGraphicsView", null ],
        [ "CGAL Ipelets", "packages.html#PkgCGALIpelets", null ],
        [ "Basic Viewer", "packages.html#PkgBasicViewer", null ]
      ] ]
    ] ],
    [ "Developer Manual", "dev_manual.html", "dev_manual" ],
    [ "License", "license.html", [
      [ "GNU GPL", "license.html#licensesGPL", null ],
      [ "GNU LGPL", "license.html#licensesLGPL", null ],
      [ "Rationale of the License Choice", "license.html#licensesRationale", null ],
      [ "Commercial Licenses", "license.html#licensesCommercial", null ],
      [ "License Checking", "license.html#licenseCheck", null ],
      [ "Determining the license of a CGAL file", "license.html#licensesWhere", null ]
    ] ],
    [ "Doxygen for CGAL", "md_Doxygen_for_CGAL.html", null ],
    [ "Acknowledging CGAL", "how_to_cite_cgal.html", null ],
    [ "Bibliography", "citelist.html", null ]
  ] ]
];

var NAVTREEINDEX =
[
"citelist.html",
"packages.html#PkgPeriodic3Triangulation3"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
